@@ -172,7 +172,7 @@ def main():
     # show the output image
     image = cv2.cvtColor(image, cv2.COLOR_BGR2RGB)
     plt.imshow(image)
-    plt.show()
+    #plt.show()
     #cv2.imshow("Output", image)
     #cv2.waitKey(0)
 
